SSTPAndroidConfiguration class

Constructors

SSTPAndroidConfiguration({bool verifyHostName = false, bool verifySSLCert = false, bool useTrustedCert = false, String sslVersion = SSLVersions.DEFAULT, bool showDisconnectOnNotification = false, String notificationText = "Connected"})

Properties

hashCode → int
The hash code for this object.
no setterinherited
notificationText → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDisconnectOnNotification → bool
final
sslVersion → String
final
useTrustedCert → bool
final
verifyHostName → bool
final
verifySSLCert → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited