SSTPIOSConfiguration class

Constructors

SSTPIOSConfiguration({bool? enableTLS = false, bool? enablePAP = false, bool? enableCHAP = false, bool? enableMSCHAP2 = true})

Properties

enableCHAP ↔ bool?
getter/setter pair
enableMSCHAP2 ↔ bool?
getter/setter pair
enablePAP ↔ bool?
getter/setter pair
enableTLS ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited