SSTPServer class

Constructors

SSTPServer({required String host, int port = 443, required String username, required String password, required SSTPAndroidConfiguration androidConfiguration, required SSTPIOSConfiguration iosConfiguration})

Properties

androidConfiguration → SSTPAndroidConfiguration
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
iosConfiguration → SSTPIOSConfiguration
final
password → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited